/**
 * @file
 * ClosedQuestion specific functions for the xmlEditor.
 */

/**
 * Set the sizes of the editor divs.
 */
function CQ_SizeEditors() {
  var divider = jQuery('#xmlJsonEditor_divider');
  var div_offset = divider.offset();
  var container = jQuery('#xmlJsonEditor_container');
  var cont_offset = container.offset();
  var tree = jQuery('#xmlJsonEditor_tree_container');
  var tree_offset = tree.offset();
  var editor = jQuery('#xmlJsonEditor_editor');
  var editor_offset = editor.offset();
  var width = container.width();
  var left = div_offset.left - cont_offset.left;
  var right = width - left - divider.width();
  divider.css('position', 'relative');
  tree.css('position', 'relative');
  editor.css('position', 'relative');
  tree_offset.top = cont_offset.top;
  editor_offset.top = cont_offset.top;
  div_offset.top = cont_offset.top;
  tree.width(left);
  tree.offset(tree_offset);
  divider.offset(div_offset);
  editor_offset.left = cont_offset.left + left + divider.width();
  editor.width(right);
  editor.offset(editor_offset);
}

/**
 * Select the tab that should be initially selected.
 * This is called by Drupal.behaviours.
 */
function CQ_InitialView() {
  var lang = Drupal.settings.closedquestion.language;
  var bodyField = '#edit-body-' + lang + '-0-value';
  if (jQuery(bodyField)[0].value.length > 0) {
    CQ_ShowTree();
  }
  else {
    CQ_ShowTemplates()
  }
}

/**
 * Shows the editor tab, loads the current XML into the editor and hides the
 * XML and templates tabs.
 */
function CQ_ShowTree() {
  var lang = Drupal.settings.closedquestion.language;
  var bodyField = '#edit-body-' + lang + '-0-value';
  jQuery('#xmlJsonEditor_tree').addClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_tree').removeClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_xml').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_xml').removeClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_templates').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_templates').removeClass('xmlJsonEditor_activeTab');

  jQuery('#edit-body').css('display', 'none');
  jQuery('#xmlJsonEditor_container').css('display', 'block');
  jQuery('#xmlJsonEditor_template_container').css('display', 'none');

  CQ_XML_config.basePath = Drupal.settings.closedquestion.basePath;
  jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('init', '#xmlJsonEditor_editor', jQuery(bodyField)[0].value, CQ_XML_config);
  jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('bind', 'change', function(data) {
    jQuery(bodyField)[0].value = jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('read');
  });

  jQuery("#xmlJsonEditor_container").resizable({
    resize: function(event, ui) {
      CQ_SizeEditors();
    }
  });
  jQuery("#xmlJsonEditor_divider").draggable({
    axis: "x",
    containment: "parent",
    start: function(event, ui) {
      jQuery("#xmlJsonEditor_container").disableSelection();
      return true;
    },
    stop: function(event, ui) {
      CQ_SizeEditors();
      jQuery("#xmlJsonEditor_container").enableSelection();
      return true;
    }
  });
  CQ_disableTextSelect(jQuery("#xmlJsonEditor_container"));
  var container = jQuery('#xmlJsonEditor_container');
  container.width(container.width());
  CQ_SizeEditors();
  /**
   * plugin matchImg editor
   */

  /* bind to before load editor */
  jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('bind', 'onLoadEditor', function(data) {
    var miEditorConfig = {};
    var matchImage, matchImageData, imageSrc, hotspotIdInput;

    jQuery('.matchImgEditor').remove();

    if (data.type == "hotspot") {
      matchImage = jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('search', 'matchimg');
      if (matchImage[0] != undefined) {
        matchImageData = matchImage[0].data();
        imageSrc = matchImageData.jstree.attributes.src;
        if (imageSrc != undefined) {
          miEditorConfig.imageURL = CQ_ParseText(imageSrc);
        }
      }
      var shapeSelect = jQuery(data.editorElements.forElement.attributeEditorElements).find("#xmlEditor_shape")[0];
      var coordsFormElement = jQuery(data.editorElements.forElement.attributeEditorElements).find("#xmlEditor_coords")[0];
      var shape = jQuery(shapeSelect).val();
      var coords = jQuery(coordsFormElement).val();

      miEditorConfig.imageFormElements = data.editorElements.forElement.attributeEditorElements;
      miEditorConfig.shapeSelect = shapeSelect;
      miEditorConfig.mode = 'edit hotspot';
      /* create matchImgEditor */
      var miEditor = new matchImgEditor(jQuery('#editor_values'), miEditorConfig);

      //set the selected shape
      jQuery(shapeSelect).change(function() {
        miEditor.clearCanvas();
        miEditor.setCurrentShape(jQuery(this).val());
      })
      miEditor.clearCanvas();
      miEditor.setCurrentShape(shape);

      //draw the shape
      if (coords != '') {
        miEditor.loadShape({
          "shape": shape,
          "coords":coords
        });
      }

      /* bind to ondrawshape event to detect changes */
      miEditor.bind('onDrawShape', function (hotspotData) {
        var dataAsString = '';
        var dataAsArray = [];

        switch (hotspotData.shape) {
          case 'circle':
            dataAsString = parseInt(hotspotData.coords.x) + ',' + parseInt(hotspotData.coords.y) + ',' + hotspotData.radius;
            break;

          default:
            jQuery(hotspotData.coords).each(function () {
              dataAsArray.push(parseInt(this.x) + ',' + parseInt(this.y));
            });
            dataAsString = dataAsArray.join(',');
            break;
        }

        jQuery(coordsFormElement).val(dataAsString);
      });
      return false;

    }
    else if (data.type == "match") {
      miEditorConfig = {};
      matchImage = jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('search', 'matchimg');
      if (matchImage[0] != undefined) {
        matchImageData = matchImage[0].data();
        imageSrc = matchImageData.jstree.attributes.src;
        if (imageSrc != undefined) {
          miEditorConfig.imageURL = CQ_ParseText(imageSrc);
        }
      }
      miEditorConfig.imageFormElements = data.editorElements.forElement.attributeEditorElements;
      miEditorConfig.shapeSelect = shapeSelect;
      miEditorConfig.mode = 'view hotspots';

      /* create matchImgEditor */
      miEditor = new matchImgEditor(jQuery('#editor_values'), miEditorConfig);
      if (miEditor.config.imageURL == undefined) {
        return true;
      }

      /* get hotspots, and draw them on the image */
      var hotspots = jQuery('#xmlJsonEditor_tree_container').xmlTreeEditor('search', 'hotspot');
      var hotspotTitleIds = [];
      // Time is used to create unique id's
      var time = new Date().getTime();
      jQuery(hotspots).each(function() {
        /* get data */
        var hotspotsData = this.data().jstree.attributes;

        //keep track of titles, so we can update them when matched
        var hotspotTitleId = 'xmlEditor_' + time + '_' + hotspotsData.id;
        hotspotTitleIds.push(hotspotTitleId);

        /* add to editor */
        miEditor.loadShape({
          "shape" : hotspotsData.shape,
          "coords" : hotspotsData.coords,
          "title" : '<span id="' + hotspotTitleId + '">' + hotspotsData.id + '</span>'
        }, true);

      });

      /* let the hotspot id input tell us when its contents change, and update
       * the corresponding shapes in the editor
       * TODO: fix selector by giving input fields proper id's
       */
      hotspotIdInput = jQuery(jQuery(miEditorConfig.imageFormElements[5]).children()[1]);
      hotspotIdInput.keyup(function () {
        var input = jQuery(this);
        var inputValue = input.val();
        jQuery(hotspotTitleIds).each(function () {
          var span = jQuery('#' + this);
          var spanText = span.html();
          try {
            var inputValueRegExp = new RegExp(inputValue);
            if (spanText.match(inputValueRegExp)) {
              span.parent().addClass('xmlJsonEditor_matched');
            }
            else {
              span.parent().removeClass('xmlJsonEditor_matched');
            }
            input.css('background-color', '');
            input.attr('title', '');
          } catch (e) {
            /* the regular expression provided is not ok */
            span.parent().removeClass('xmlJsonEditor_matched');
            input.css('background-color', '#fcc');
            input.attr('title', 'This is not a correct regular expression');
          }
        });
      });
      hotspotIdInput.keyup(); // run it for the first time.

      return false;
    }
    else {
      /* destroy matchImgEditors */
      jQuery('.matchImgEditor').remove();
      
      return true;
    }

  });
  return true;
}

/**
 * Shows the XML tab and hides the editor and templates tabs.
 */
function CQ_ShowXML() {
  jQuery('#xmlJsonEditor_tree').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_tree').removeClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_xml').addClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_xml').removeClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_templates').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_templates').removeClass('xmlJsonEditor_activeTab');

  jQuery('#xmlJsonEditor_container').css('display', 'none');
  jQuery('#edit-body').css('display', 'block');
  jQuery('#xmlJsonEditor_template_container').css('display', 'none');
}

/**
 * Shows the templates tab and hides the editor and XML tabs.
 */
function CQ_ShowTemplates() {
  jQuery('#xmlJsonEditor_tree').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_tree').removeClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_xml').addClass('xmlJsonEditor_inactiveTab');
  jQuery('#xmlJsonEditor_xml').removeClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_templates').addClass('xmlJsonEditor_activeTab');
  jQuery('#xmlJsonEditor_templates').removeClass('xmlJsonEditor_inactiveTab');

  jQuery('#xmlJsonEditor_container').css('display', 'none');
  jQuery('#edit-body').css('display', 'none');
  jQuery('#xmlJsonEditor_template_container').css('display', 'block');
}

/**
 * Posts the text, with the form-id to the server so the server can parse the
 * text for any tags, and return the replaced text.
 */
function CQ_ParseText(text) {
  var form_id = jQuery('[name=form_build_id]')[0];
  var target_url = Drupal.settings.basePath + 'closedquestion/parsecontentjs';
  var result = jQuery.ajax({
    url: target_url,
    data: {
      form_build_id : form_id.value,
      parse_content : text
    },
    async: false
  }).responseText;
  var obj = jQuery.parseJSON(result);
  return obj.data;
}

/**
 * Loads a template into the editor. Gives a warning if the editor is not empty.
 *
 * @param template
 *   The XML string to load.
 */
function CQ_LoadTemplate(template) {
  var lang = Drupal.settings.closedquestion.language;
  var bodyField = '#edit-body-' + lang + '-0-value';
  var confirmed = true;
  if (jQuery(bodyField)[0].value.length > 0) {
    confirmed = confirm("Loading this template will overwrite your current question. Are you sure?");
  }
  if (confirmed) {
    jQuery(bodyField)[0].value = template;
    CQ_ShowTree();
  }
}

/**
 * Creates the xml for an empty multiple-choice question, loads it and switches
 * to the editor tab.
 */
function QC_CreateMC() {
  CQ_LoadTemplate('\
<question type="OPTION">\n\
  <text>Put the question here</text>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <option correct="0">\n\
    <choice>Option 1</choice>\n\
    <feedback>feedback for option 1</feedback>\n\
  </option>\n\
  <option correct="0">\n\
    <choice>Option 2</choice>\n\
    <feedback>feedback for option 2</feedback>\n\
  </option>\n\
  <option correct="1">\n\
    <choice>Option 3</choice>\n\
    <feedback>feedback for option 3</feedback>\n\
  </option>\n\
  <option correct="0">\n\
    <choice>Option 4</choice>\n\
    <feedback>feedback for option 4</feedback>\n\
  </option>\n\
</question>');
}

/**
 * Creates the xml for an empty multiple-answer question, loads it and switches
 * to the editor tab.
 */
function QC_CreateMA() {
  CQ_LoadTemplate('\
<question type="CHECK">\n\
  <text>Put the question here</text>\n\
  <correct>Feedback if the student answers the question correct.</correct>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <option>\n\
    <choice>Option 1</choice>\n\
    <feedback>feedback for option 1</feedback>\n\
  </option>\n\
  <option correct="1">\n\
    <choice>Option 2</choice>\n\
    <feedback>feedback for option 2</feedback>\n\
  </option>\n\
  <option correct="1">\n\
    <choice>Option 3</choice>\n\
    <feedback>feedback for option 3</feedback>\n\
  </option>\n\
  <option>\n\
    <choice>Option 4</choice>\n\
    <feedback>feedback for option 4</feedback>\n\
  </option>\n\
</question>');
}

/**
 * Creates the xml for an empty multiple-answer question with advanced response
 * processing, loads it and switches to the editor tab.
 */
function QC_CreateMAA() {
  CQ_LoadTemplate('\
<question type="CHECK">\n\
  <text>Put the question here</text>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <option id="a">\n\
    <choice>Option 1</choice>\n\
  </option>\n\
  <option id="b">\n\
    <choice>Option 2</choice>\n\
  </option>\n\
  <option id="c">\n\
    <choice>Option 3</choice>\n\
  </option>\n\
  <option id="d">\n\
    <choice>Option 4</choice>\n\
  </option>\n\
  <mapping correct="1">\n\
    <match pattern="a" />\n\
    <match pattern="c" />\n\
    <feedback>That is correct.</feedback>\n\
  </mapping>\n\
</question>');
}

/**
 * Creates the xml for an empty Select&Order question, loads it and switches
 * to the editor tab.
 */
function QC_CreateSO1() {
  CQ_LoadTemplate('\
<question type="selectorder" duplicates="0">\n\
  <text>Select and order the needed steps. This example question contains only one target box.</text>\n\
  <option id="a">\n\
    <choice>Step A.</choice>\n\
  </option>\n\
  <option id="b">\n\
    <choice>Step B.</choice>\n\
  </option>\n\
  <option id="c">\n\
    <choice>Step C.</choice>\n\
  </option>\n\
  <option id="d">\n\
    <choice>Step D.</choice>\n\
  </option>\n\
  <option id="e">\n\
    <choice>Step E.</choice>\n\
  </option>\n\
  <option id="f">\n\
    <choice>Step F.</choice>\n\
  </option>\n\
    <hint mintries="1">A first hint.</hint>\n\
    <hint mintries="2">A second hint.</hint>\n\
    <hint mintries="3">A third hint.</hint>\n\
  <mapping correct="1">\n\
    <match pattern="^bcd$" />\n\
    <feedback>Correct. You only need steps B, C and D.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <match pattern="^[^b]*c.*$" />\n\
    <feedback>You can not do step C unless you first do step B.</feedback>\n\
  </mapping>\n\
</question>');
}

/**
 * Creates the xml for an empty Select&Order question with multile target boxes,
 * loads it and switches to the editor tab.
 */
function QC_CreateSO2() {
  CQ_LoadTemplate('\
<question type="selectorder">\n\
  <text>Select and order the needed steps. This example question contains only one target box.</text>\n\
  <option id="a">\n\
    <choice>Step A.</choice>\n\
  </option>\n\
  <option id="b">\n\
    <choice>Step B.</choice>\n\
  </option>\n\
  <option id="c">\n\
    <choice>Step C.</choice>\n\
  </option>\n\
  <option id="d">\n\
    <choice>Step D.</choice>\n\
  </option>\n\
  <option id="e">\n\
    <choice>Step E.</choice>\n\
  </option>\n\
  <option id="f">\n\
    <choice>Step F.</choice>\n\
  </option>\n\
  <option id="1"><choice>Day 1</choice></option>\n\
  <option id="2"><choice>Day 2</choice></option>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <mapping correct="1">\n\
    <match pattern="^1bc2d$" />\n\
    <feedback>Correct. You need to do steps B and C on day 1 and step D on day 2.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <match pattern="^[^b]*c.*$" />\n\
    <feedback>You can not do step C unless you first do step B.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <match pattern="([^d12]d)|(d[^d12])" />\n\
    <feedback>Step D is an all-day event, you can not combine it with other\n\
    steps on the same day.</feedback>\n\
  </mapping>\n\
</question>');
}

/**
 * Creates the xml for an empty hotspot question, loads it and switches to the
 * editor tab.
 */
function QC_CreateHS() {
  CQ_LoadTemplate('\
<question type="hotspot">\n\
  <text><p>Point out the correct two items.</p></text>\n\
  <matchImg src="[attachurl:1]" maxChoices="2">\n\
    <hotspot id="A" shape="circle" coords="275,68,68">Hotspot A.</hotspot>\n\
    <hotspot id="B" shape="rect" coords="0,21,43,121"></hotspot>\n\
    <hotspot id="C" shape="poly" coords="174,282,258,293,320,318,366,360,267,468,207,438,149,443,99,465,85,486,7,416,7,354,64,307">Hotspot C.</hotspot>\n\
  </matchImg>\n\
   <hint mintries="1">A first hint.</hint>\n\
   <hint mintries="2">A second hint.</hint>\n\
   <hint mintries="3">A third hint.</hint>\n\
  <mapping correct="1">\n\
    <match hotspot="A" />\n\
    <match hotspot="B" />\n\
    <feedback>Very Good, you pointed out the correct two items</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <match hotspot="C" />\n\
    <feedback>You have pointed out an incorrect item.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <not><match hotspot="A" /></not>\n\
    <feedback>You have not pointed out the first correct item.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <not>\n\
      <or>\n\
        <match hotspot="A" />\n\
        <match hotspot="B" />\n\
        <match hotspot="C" />\n\
      </or>\n\
    </not>\n\
    <feedback mintries="1">You have not selected any item.</feedback>\n\
  </mapping>\n\
</question>');
}

/**
 * Creates the xml for an empty hotspot question, loads it and switches to the
 * editor tab.
 */
function QC_CreateDD() {
  CQ_LoadTemplate('\
<question type="dragdrop">\n\
  <text>Drag the items to the corresponding locations on the image.</text>\n\
  <matchImg src="[attachurl:1]">\n\
    <hotspot shape="rect" coords="2,91,119,124" identifier="h1" />\n\
    <hotspot shape="circle" coords="6,196,123" identifier="h2" />\n\
    <hotspot shape="poly" coords="6,268,6,301,153,301,123,208" identifier="h3" />\n\
    <draggable identifier="d1">Draggable 1</draggable>\n\
    <draggable identifier="d2">Draggable 2</draggable>\n\
    <draggable identifier="d3">Draggable 3</draggable>\n\
  </matchImg>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <mapping correct="1">\n\
    <combination hotspot="h1" draggable="d1" />\n\
    <combination hotspot="h2" draggable="d2" />\n\
    <combination hotspot="h3" draggable="d3" />\n\
    <feedback>Correct. You have put the items at the right locations.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <combination hotspotpattern="h.*" draggablepattern="d[0-9]" />\n\
    <feedback>You have at least one draggable on one hotspot.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <combination hotspot="h1" draggablepattern="d[0-9]" />\n\
    <feedback>You have at least one draggable on hotspot 1.</feedback>\n\
  </mapping>\n\
  <mapping correct="0">\n\
    <combination hotspotpattern="h.*" draggable="d1" />\n\
    <feedback>You have draggable 1 on a hotspot.</feedback>\n\
  </mapping>\n\
</question>');
}

/**
 * Creates the xml for an empty FillBlanks question, loads it and switches to
 * the editor tab.
 */
function QC_CreateFB1() {
  CQ_LoadTemplate('\
<question type="fillblanks">\n\
  <matheval expression="a=random()" store="1" />\n\
  <matheval expression="b=random()" store="1" />\n\
  <matheval expression="a=round(a*0.8+0.11,2)" />\n\
  <matheval expression="b=round(b*5+2,0)" />\n\
  <matheval expression="ans=a*b" />\n\
  <matheval expression="min=ans-0.01" />\n\
  <matheval expression="max=ans+0.01" />\n\
  <text><p>You have measured a concentration of <mathresult expression="a" />mg/ml in a <mathresult expression="b" />-times diluted sample.<br/>\n\
What was the concentration in the non-diluted solution?</p>\n\
<p><b>The original concentration was: <inlineChoice identifier="c" freeform="1" />g/l</b></p></text>\n\
  <hint mintries="1">A first hint.</hint>\n\
  <hint mintries="2">A second hint.</hint>\n\
  <hint mintries="3">A third hint.</hint>\n\
  <mapping correct="1">\n\
    <range inlineChoice="c" minval="min" maxval="max" />\n\
    <feedback>Very good. The difference between your answer and the "real" answer is: <mathresult e="abs(ans-c)" /></feedback>\n\
  </mapping>\n\
  <mapping correct="0" stop="1">\n\
    <not><match inlineChoice="c" pattern="^[+-]?[0-9]+([,.][0-9]+)?([eE][+-]?[0-9]+)?$" /></not>\n\
    <feedback>Please give a number.</feedback>\n\
  </mapping>\n\
</question>');
}
